@@ -23,24 +23,23 @@
 
 (defvar *html-output* *standard-output*)
 
-(defmacro lml-file-name (file &optional (type :source))
-  (let ((f file))
-    (when (and (consp f) (eql (car f) 'cl:quote))
-      (setq f (cadr f)))
-    (when (symbolp f)
-      (setq f (string-downcase (symbol-name f))))
-    (when (stringp f)
-      (unless (position #\. f)
-	(setq f (concatenate 'string f ".html"))))
-    (if *sources-dir*
-	(make-pathname :defaults (ecase type
-				   (:source *sources-dir*)
-				   (:output *output-dir*))
-		       :name `,(pathname-name f)
-		       :type `,(pathname-type f))
+(defun lml-file-name (f &optional (type :source))
+  (when (and (consp f) (eql (car f) 'cl:quote))
+    (setq f (cadr f)))
+  (when (symbolp f)
+    (setq f (string-downcase (symbol-name f))))
+  (when (stringp f)
+    (unless (position #\. f)
+      (setq f (concatenate 'string f ".html"))))
+  (if *sources-dir*
+      (make-pathname :defaults (ecase type
+				 (:source *sources-dir*)
+				 (:output *output-dir*))
+		     :name (pathname-name f)
+		     :type (pathname-type f))
       (if (stringp f)
-	  (parse-namestring f)
-	f))))
+	  (nth-value 0 (parse-namestring f))
+	  f)))
 
 (defmacro with-dir ((output &key sources) &body body)
   (let ((output-dir (gensym))
