@@ -2,50 +2,46 @@
 ;;;; *************************************************************************
 ;;;; FILE IDENTIFICATION
 ;;;;
-;;;; Name:          package.lisp
-;;;; Purpose:       Package file for Lisp Markup Language 2
+;;;; Name:          package.cl
+;;;; Purpose:       Package file for Lisp Markup Language
 ;;;; Programmer:    Kevin M. Rosenberg
-;;;; Date Started:  June 2003
+;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id$
+;;;; $Id: package.lisp 7061 2003-09-07 06:34:45Z kevin $
 ;;;;
-;;;; This file, part of LML2, is Copyright (c) 2000-2003 by Kevin Rosenberg.
-;;;; Rights of modification and redistribution are in the LICENSE file.
+;;;; This file, part of LML, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
+;;;; LML users are granted the rights to distribute and use this software
+;;;; as governed by the terms of the GNU General Public License v2
+;;;; (http://www.gnu.org/licenses/gpl.html)
 ;;;; *************************************************************************
 
 (in-package #:cl-user)
 
-(defpackage #:lisp-markup-language-2
-  (:use #:common-lisp #:kmrcl)
-  (:nicknames #:lml2)
+(defpackage #:lisp-markup-language
+  (:use #:common-lisp)
+  (:nicknames #:lml)
   (:export
 
-   ;; data.lisp
-   #:*html-stream*
-
    ;; base.lisp
-   #:html-file-page
-   #:dtd-prologue
+   #:*print-spaces*
+   #:reset-indent
+   #:with
+   #:print-page
+   #:page
    #:lml-format
    #:lml-print
    #:lml-princ
    #:lml-write-char
    #:lml-write-string
    #:lml-print-date
-   #:alink
-   #:alink-c
-
-   ;; htmlgen.lisp
-   #:html #:html-print #:html-print-subst #:html-print-list #:html-print-list-subst
-   #:html-stream #:*html-stream*
-
-
+   #:*html-output*
+   
    ;; files.lisp
    #:with-dir
    #:process-dir
    #:lml-load
-   #:insert-file
+   #:include-file
 
    ;; stdsite.lisp
    #:print-std-page
@@ -53,7 +49,7 @@
    #:std-body
    #:std-head
    #:titled-pre-section
-
+   
    ;; downloads.lisp
    #:std-dl-page
    #:full-dl-page
@@ -61,7 +57,4 @@
    ;; utils.lisp
    #:lml-quit
    #:lml-cwd
-
-   ;; apache-dir
-   #:write-html-apache-directory
 ))
